@@ -1,12 +1,11 @@
 import numpy as np
-from tqdm import tqdm
 
 from copy import deepcopy
 
 import torch
 import torch.nn.functional as F
 
-from mushroom_rl.algorithms.agent import Agent
+from mushroom_rl.core import Agent
 from mushroom_rl.approximators import Regressor
 from mushroom_rl.approximators.parametric import TorchApproximator
 from mushroom_rl.utils.torch import get_gradient, zero_grad, to_float_tensor
