@@ -3,5 +3,6 @@ from .rwr import RWR
 from .reps import REPS
 from .pgpe import PGPE
 from .constrained_reps import ConstrainedREPS
+from .more import MORE
 
-__all__ = ['RWR', 'PGPE', 'REPS', 'ConstrainedREPS']
\ No newline at end of file
+__all__ = ['RWR', 'PGPE', 'REPS', 'ConstrainedREPS', 'MORE']
\ No newline at end of file
