@@ -1,6 +1,6 @@
 import numpy as np
 
-from mushroom_rl.algorithms.agent import Agent
+from mushroom_rl.core import Agent
 from mushroom_rl.utils.dataset import compute_J
 
 
