@@ -74,9 +74,12 @@ class TorchApproximator(Serializable):
             _n_fit_targets='primitive',
             network='torch',
             _optimizer='torch',
-            _loss='pickle'
+            _loss='pickle',
+            _last_loss='none'
         )
 
+        self._last_loss = None
+
     def predict(self, *args, output_tensor=False, **kwargs):
         """
         Predict.
@@ -196,6 +199,8 @@ class TorchApproximator(Serializable):
                     else:
                         patience_count += 1
 
+                    self._last_loss = mean_loss_current
+
                     epochs_count += 1
         else:
             with trange(n_epochs, disable=self._quiet) as t_epochs:
@@ -206,6 +211,8 @@ class TorchApproximator(Serializable):
                     if not self._quiet:
                         t_epochs.set_postfix(loss=mean_loss_current)
 
+                    self._last_loss = mean_loss_current
+
         if self._dropout:
             self.network.eval()
 
@@ -219,7 +226,9 @@ class TorchApproximator(Serializable):
         for batch in batches:
             loss_current.append(self._fit_batch(batch, use_weights, kwargs))
 
-        return np.mean(loss_current)
+        mean_loss_current = np.mean(loss_current)
+
+        return mean_loss_current
 
     def _fit_batch(self, batch, use_weights, kwargs):
         loss = self._compute_batch_loss(batch, use_weights, kwargs)
@@ -341,6 +350,10 @@ class TorchApproximator(Serializable):
     def use_cuda(self):
         return self._use_cuda
 
+    @property
+    def loss_fit(self):
+        return self._last_loss
+
     def _post_load(self):
         if self._optimizer is not None:
             update_optimizer_parameters(self._optimizer, list(self.network.parameters()))
