@@ -55,6 +55,7 @@ class Regressor(Serializable):
 
         self.n_actions = n_actions
         self._n_models = n_models
+        self._logger = None
 
         if self._n_models is not None:
             assert self._n_models >= 1
@@ -73,12 +74,16 @@ class Regressor(Serializable):
                                           len(self.input_shape),
                                           **params)
 
+        self._logger = None
+        self._loss_filename = None
+
         self._add_save_attr(
             _input_shape='primitive',
             _output_shape='primitive',
             n_actions='primitive',
             _n_models='primitive',
-            _impl='mushroom'
+            _impl='mushroom',
+            _logger='none'
         )
 
     def __call__(self, *z, **predict_params):
@@ -107,6 +112,8 @@ class Regressor(Serializable):
             z = [np.expand_dims(z_i, axis=0) for z_i in z]
         self._impl.fit(*z, **fit_params)
 
+        self._log()
+
     def predict(self, *z, **predict_params):
         """
         Predict the output of the model given an input.
@@ -228,3 +235,37 @@ class Regressor(Serializable):
             return self.model
         else:
             return self.model[item]
+
+    def set_logger(self, logger, loss_filename=None):
+        """
+        Setter that can be used to pass a logger to the regressor.
+
+        Args:
+            logger (Logger): the logger to be used by the regressor;
+            loss_filename (str, None): optional string to specify the loss filename.
+
+        """
+        self._logger = logger
+        self._loss_filename = loss_filename
+
+    def _log(self):
+        if self._logger:
+            losses_fit = list()
+            for i in range(len(self)):
+                model_i = self[i]
+                if hasattr(model_i, 'loss_fit'):
+                    m_loss = model_i.loss_fit
+                    if hasattr(m_loss, 'squeeze'):
+                        m_loss = m_loss.squeeze()
+                    losses_fit.append(m_loss)
+
+            losses_fit = np.array(losses_fit).squeeze()
+
+            if self._loss_filename is None:
+                save_dict = dict(loss=losses_fit)
+            else:
+                save_dict = {self._loss_filename: losses_fit}
+
+            self._logger.log_numpy(**save_dict)
+
+
