@@ -1,5 +1,5 @@
 from .policy import Policy, ParametricPolicy
-from .noise_policy import OrnsteinUhlenbeckPolicy
+from .noise_policy import OrnsteinUhlenbeckPolicy, ClippedGaussianPolicy
 from .td_policy import TDPolicy, Boltzmann, EpsGreedy, Mellowmax
 from .gaussian_policy import GaussianPolicy, DiagonalGaussianPolicy, \
      StateStdGaussianPolicy, StateLogStdGaussianPolicy
@@ -13,5 +13,5 @@ __all_parametric__ = ['ParametricPolicy', 'GaussianPolicy',
                       'StateLogStdGaussianPolicy']
 __all_torch__ = ['TorchPolicy', 'GaussianTorchPolicy', 'BoltzmannTorchPolicy']
 
-__all__ = ['Policy',  'DeterministicPolicy', 'OrnsteinUhlenbeckPolicy'] \
+__all__ = ['Policy',  'DeterministicPolicy', 'OrnsteinUhlenbeckPolicy', 'ClippedGaussianPolicy'] \
           + __all_td__ + __all_parametric__ + __all_torch__
