@@ -1,8 +1,16 @@
+from mushroom_rl.core import Serializable
 from mushroom_rl.utils.table import Table
 import numpy as np
 
 
-class Parameter(object):
+def to_parameter(x):
+    if isinstance(x, Parameter):
+        return x
+    else:
+        return Parameter(x)
+
+
+class Parameter(Serializable):
     """
     This class implements function to manage parameters, such as learning rate.
     It also allows to have a single parameter for each state of state-action
@@ -29,6 +37,13 @@ class Parameter(object):
         self._max_value = max_value
         self._n_updates = Table(size)
 
+        self._add_save_attr(
+            _initial_value='primitive',
+            _min_value='primitive',
+            _max_value='primitive',
+            _n_updates='mushroom',
+        )
+
     def __call__(self, *idx, **kwargs):
         """
         Update and return the parameter in the provided index.
@@ -117,6 +132,8 @@ class LinearParameter(Parameter):
         else:
             super().__init__(value, threshold_value, None, size)
 
+        self._add_save_attr(_coeff='primitive')
+
     def _compute(self, *idx, **kwargs):
         return self._coeff * self._n_updates[idx] + self._initial_value
 
@@ -133,53 +150,10 @@ class ExponentialParameter(Parameter):
 
         super().__init__(value, min_value, max_value, size)
 
+        self._add_save_attr(_exp='primitive')
+
     def _compute(self, *idx, **kwargs):
         n = np.maximum(self._n_updates[idx], 1)
 
         return self._initial_value / n ** self._exp
 
-
-class AdaptiveParameter(object):
-    """
-    This class implements a basic adaptive gradient step. Instead of moving of
-    a step proportional to the gradient, takes a step limited by a given metric.
-    To specify the metric, the natural gradient has to be provided. If natural
-    gradient is not provided, the identity matrix is used.
-
-    The step rule is:
-
-    .. math::
-        \\Delta\\theta=\\underset{\\Delta\\vartheta}{argmax}\\Delta\\vartheta^{t}\\nabla_{\\theta}J
-
-        s.t.:\\Delta\\vartheta^{T}M\\Delta\\vartheta\\leq\\varepsilon
-
-    Lecture notes, Neumann G.
-    http://www.ias.informatik.tu-darmstadt.de/uploads/Geri/lecture-notes-constraint.pdf
-
-    """
-    def __init__(self, value):
-        self._eps = value
-
-    def __call__(self, *args, **kwargs):
-        return self.get_value(*args, **kwargs)
-
-    def get_value(self, *args, **kwargs):
-        if len(args) == 2:
-            gradient = args[0]
-            nat_gradient = args[1]
-            tmp = (gradient.dot(nat_gradient)).item()
-            lambda_v = np.sqrt(tmp / (4. * self._eps))
-            # For numerical stability
-            lambda_v = max(lambda_v, 1e-8)
-            step_length = 1. / (2. * lambda_v)
-
-            return step_length
-        elif len(args) == 1:
-            return self.get_value(args[0], args[0], **kwargs)
-        else:
-            raise ValueError('Adaptive parameters needs gradient or gradient'
-                             'and natural gradient')
-
-    @property
-    def shape(self):
-        return None
